import { Injectable } from '@nestjs/common'

import { ServiceResponse } from '@/response/response.interface'
import { HttpClientService } from '@/shared/http-client/http-client.service'

@Injectable()
export class AgentModuleHttpService {
  private readonly baseUrl = 'http://192.168.206.189:8083/api'

  constructor(private readonly httpClientService: HttpClientService) {}

  private async makeRequest<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    const url = `${this.baseUrl}/${endpoint}`
    return this.httpClientService.get<T>(url, params)
  }

  async makeRequestPost<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    const url = `${this.baseUrl}/${endpoint}`
    return this.httpClientService.post<T>(url, params)
  }

  async getModuleList(): Promise<ServiceResponse<ModuleConfigurationType[]>> {
    return this.makeRequest<ModuleConfigurationType[]>('getModuleList')
  }

  async getModuleConfiguration(
    module_id: number
  ): Promise<ServiceResponse<ModuleConfigurationType>> {
    return this.makeRequest<ModuleConfigurationType>('getModuleConfiguration', {
      module_id
    })
  }

  async saveModuleConfiguration(
    module_id: number,
    name: string,
    display_name: string,
    default_agent_type: number,
    default_agent_id: number
  ): Promise<ServiceResponse<any>> {
    return this.makeRequestPost<any>('saveModuleConfiguration', {
      module_id,
      name,
      display_name,
      default_agent_type,
      default_agent_id
    })
  }

  async getModuleAgentTypes(): Promise<ServiceResponse<any>> {
    return this.makeRequest<any>('getModuleAgentTypes')
  }
}
