import { Controller, Get, Query, Post, Body, Header } from '@nestjs/common'
import { ApiOperation, ApiTags } from '@nestjs/swagger'

import {
  GetDialogueHistoryDto,
  GetBasePromptDto,
  GetUserProfileDto,
  GetStaffProfileDto,
  RunPromptDto,
  ListUsersDto,
  FormatForPromptDto
} from '@/dto/agent-server'

import { AgentServerService } from './service/agent-server.service'

@ApiTags('agent-server')
@Controller('agent-server')
export class AgentServerController {
  constructor(private readonly agentServerService: AgentServerService) {}

  @Get('staffs')
  @ApiOperation({ summary: '获取客服列表' })
  async listStaffs() {
    return this.agentServerService.listStaffs()
  }

  @Get('dialogue/history')
  @ApiOperation({ summary: '获取对话历史' })
  async getDialogueHistory(@Query() query: GetDialogueHistoryDto) {
    return this.agentServerService.getDialogueHistory(
      query.staffId,
      query.userName,
      query.unionId,
      query.recentMinutes
    )
  }

  @Get('scenes')
  @ApiOperation({ summary: '获取场景列表' })
  async listScenes() {
    return this.agentServerService.listScenes()
  }

  @Get('models')
  @ApiOperation({ summary: '获取模型列表' })
  async listModels() {
    return this.agentServerService.listModels()
  }

  @Get('user/profile')
  @ApiOperation({ summary: '获取用户信息' })
  async getUserProfile(@Query() query: GetUserProfileDto) {
    return this.agentServerService.getUserProfile(query.userId)
  }

  @Get('staff/profile')
  @ApiOperation({ summary: '获取客服信息' })
  async getStaffProfile(@Query() query: GetStaffProfileDto) {
    return this.agentServerService.getStaffProfile(query.staffId)
  }

  @Get('base-prompt')
  @ApiOperation({ summary: '获取基础提示词' })
  async getBasePrompt(@Query() query: GetBasePromptDto) {
    return this.agentServerService.getBasePrompt(query.scene)
  }

  @Post('run-prompt')
  @Header('Content-Type', 'application/json')
  @ApiOperation({ summary: '运行提示词' })
  async runPrompt(@Body() body: RunPromptDto) {
    return this.agentServerService.runPrompt(body)
  }

  @Get('user/list')
  @ApiOperation({ summary: '获取用户列表' })
  async listUsers(@Query() query: ListUsersDto) {
    return this.agentServerService.listUsers(query.userName, query.unionId)
  }

  @Post('format-for-prompt')
  @Header('Content-Type', 'application/json')
  @ApiOperation({ summary: '格式化提示词' })
  async formatForPrompt(@Body() body: FormatForPromptDto) {
    return this.agentServerService.formatForPrompt(body)
  }
}
