import { Injectable } from '@nestjs/common'

import { ServiceResponse } from '@/response/response.interface'
import { HttpClientService } from '@/shared/http-client/http-client.service'

@Injectable()
export class AgentTestHttpService {
  private readonly baseUrl = 'http://192.168.206.189:8083/api'

  constructor(private readonly httpClientService: HttpClientService) {}

  private async makeRequest<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    const url = `${this.baseUrl}/${endpoint}`
    return this.httpClientService.get<T>(url, params)
  }

  async makeRequestPost<T>(
    endpoint: string,
    params?: Record<string, any>
  ): Promise<ServiceResponse<T>> {
    const url = `${this.baseUrl}/${endpoint}`
    return this.httpClientService.post<T>(url, params)
  }

  async createTestTask(
    params: Record<string, any>
  ): Promise<ServiceResponse<TestTaskType>> {
    return this.makeRequestPost<TestTaskType>('createTestTask', params)
  }

  async getEvaluteType(): Promise<ServiceResponse<EvaluteType>> {
    return this.makeRequestPost<EvaluteType>('getEvaluteType')
  }

  async getTestTaskList(
    params: Record<string, any>
  ): Promise<ServiceResponse<TestTaskListType>> {
    return this.makeRequestPost<TestTaskListType>('getTestTaskList', params)
  }

  async stopTestTask(
    params: Record<string, any>
  ): Promise<ServiceResponse<any>> {
    return this.makeRequestPost<any>('stopTestTask', params)
  }

  async resumeTestTask(
    params: Record<string, any>
  ): Promise<ServiceResponse<any>> {
    return this.makeRequestPost<any>('resumeTestTask', params)
  }

  async getTestTaskConversations(
    params: Record<string, any>
  ): Promise<ServiceResponse<TaskConversationsType>> {
    return this.makeRequest<TaskConversationsType>(
      'getTestTaskConversations',
      params
    )
  }
}
